(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     13533,        451]
NotebookOptionsPosition[     12160,        402]
NotebookOutlinePosition[     12501,        417]
CellTagsIndexPosition[     12458,        414]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
GAUSS-LEGENDRE QUADRATURE.

CASE: n = 2

The roots of the Legendre polynomial P_n are the quadrature nodes.\
\>", "Text",
 CellChangeTimes->{{3.50453896859978*^9, 3.504538988318841*^9}, {
  3.504539554096192*^9, 3.50453957024023*^9}, {3.5045397659682493`*^9, 
  3.504539767567966*^9}}],

Cell[BoxData[
 RowBox[{"r", " ", ":=", " ", 
  RowBox[{"Roots", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"LegendreP", "[", 
      RowBox[{"2", ",", "x"}], "]"}], "\[Equal]", "0"}], ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.504129388273831*^9, 3.5041293883663177`*^9}, {
   3.504538925369725*^9, 3.504538927078896*^9}, 3.5045393326456127`*^9, {
   3.504539399581994*^9, 3.504539400509843*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", " ", "=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"r", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5045393742153683`*^9, 3.504539414190461*^9}, {
  3.504539447624114*^9, 3.5045394477026987`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["3"]], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["3"]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5045393764344378`*^9, 3.504539414998663*^9}, {
   3.504539448053575*^9, 3.504539452727515*^9}, 3.504539799039611*^9}]
}, Open  ]],

Cell["\<\
Construct kernel matrix using all Legendre polynomials up to P_{n-1} at the \
quadrature nodes.\
\>", "Text",
 CellChangeTimes->{{3.50453902161764*^9, 3.504539054344022*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"K", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LegendreP", "[", 
        RowBox[{"0", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"LegendreP", "[", 
        RowBox[{"0", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LegendreP", "[", 
        RowBox[{"1", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"LegendreP", "[", 
        RowBox[{"1", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.504119879573515*^9, 3.5041198846549397`*^9}, {
   3.504119922089546*^9, 3.504119938688884*^9}, {3.504128797869638*^9, 
   3.504128850572871*^9}, {3.504539064437107*^9, 3.504539080042802*^9}, 
   3.504539698000618*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "K", "]"}]], "Input",
 CellChangeTimes->{{3.504539700502472*^9, 3.504539704101507*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1"},
     {
      FractionBox["1", 
       SqrtBox["3"]], 
      RowBox[{"-", 
       FractionBox["1", 
        SqrtBox["3"]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.504539704525477*^9, 3.504539799106524*^9}]
}, Open  ]],

Cell["\<\
Scaling factor for sampling matrix which corrects for the scaling factor of \
the first basis function coefficient, which, up to this constant, is the \
sought integral.\
\>", "Text",
 CellChangeTimes->{{3.504539198754526*^9, 3.504539257642024*^9}}],

Cell[BoxData[
 RowBox[{"n", " ", ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"LegendreP", "[", 
     RowBox[{"0", ",", "x"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.50412885636887*^9, 3.504128903893149*^9}, {
   3.5045391828039417`*^9, 3.504539192161935*^9}, 3.504539265366478*^9}],

Cell["\<\
Sampling matrix, with scaling factor. The first column are the weights of \
Gauss-Legendre quadrature (compare for example with \
http://en.wikipedia.org/wiki/Gaussian_quadrature).\
\>", "Text",
 CellChangeTimes->{{3.504539274117157*^9, 3.5045392919307528`*^9}, {
  3.5045395102396383`*^9, 3.504539542799664*^9}}],

Cell[BoxData[
 RowBox[{"S", " ", ":=", " ", 
  RowBox[{"n", "*", " ", 
   RowBox[{"Inverse", "[", "K", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.504539279156638*^9, 3.504539301054453*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "S", "]"}]], "Input",
 CellChangeTimes->{{3.504539307338067*^9, 3.504539311972167*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      SqrtBox["3"]},
     {"1", 
      RowBox[{"-", 
       SqrtBox["3"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.504539312381506*^9, {3.50453943808344*^9, 3.504539460340817*^9}, 
   3.504539799206108*^9}]
}, Open  ]],

Cell["CASE: n = 3", "Text",
 CellChangeTimes->{{3.504539575424593*^9, 3.50453957638408*^9}, {
  3.5045397711039248`*^9, 3.504539773447386*^9}}],

Cell[BoxData[
 RowBox[{"r", " ", ":=", " ", 
  RowBox[{"Roots", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"LegendreP", "[", 
      RowBox[{"3", ",", "x"}], "]"}], "\[Equal]", "0"}], ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.504539596233665*^9, 3.5045396042259893`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", " ", "=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"r", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
    RowBox[{
     RowBox[{"r", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.504539615385765*^9, 3.504539649394656*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   SqrtBox[
    FractionBox["3", "5"]], ",", 
   RowBox[{"-", 
    SqrtBox[
     FractionBox["3", "5"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5045396499936113`*^9, 3.504539799272305*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"K", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LegendreP", "[", 
        RowBox[{"0", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"LegendreP", "[", 
        RowBox[{"0", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"LegendreP", "[", 
        RowBox[{"0", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LegendreP", "[", 
        RowBox[{"1", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"LegendreP", "[", 
        RowBox[{"1", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"LegendreP", "[", 
        RowBox[{"1", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LegendreP", "[", 
        RowBox[{"2", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"LegendreP", "[", 
        RowBox[{"2", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"LegendreP", "[", 
        RowBox[{"2", ",", 
         RowBox[{"r", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.504129268450705*^9, 3.504129305583992*^9}, {
  3.5045396579792128`*^9, 3.504539689392762*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "K", "]"}]], "Input",
 CellChangeTimes->{{3.50453971231828*^9, 3.504539716540945*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "1"},
     {"0", 
      SqrtBox[
       FractionBox["3", "5"]], 
      RowBox[{"-", 
       SqrtBox[
        FractionBox["3", "5"]]}]},
     {
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["2", "5"], 
      FractionBox["2", "5"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.5045397169603453`*^9, 3.5045397220186*^9}, 
   3.5045397993563547`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", " ", ":=", " ", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"LegendreP", "[", 
      RowBox[{"0", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.504129308867242*^9, 3.504129342052404*^9}, {
  3.504539726687005*^9, 3.5045397339242773`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"S", ":=", " ", 
   RowBox[{"n", " ", "*", " ", 
    RowBox[{"Inverse", "[", "K", "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.504539738227662*^9, 3.504539742419505*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "S", "]"}]], "Input",
 CellChangeTimes->{{3.5045397434363832`*^9, 3.504539746275104*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["8", "9"], "0", 
      RowBox[{"-", 
       FractionBox["20", "9"]}]},
     {
      FractionBox["5", "9"], 
      SqrtBox[
       FractionBox["5", "3"]], 
      FractionBox["10", "9"]},
     {
      FractionBox["5", "9"], 
      RowBox[{"-", 
       SqrtBox[
        FractionBox["5", "3"]]}], 
      FractionBox["10", "9"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5045397478601923`*^9, 3.5045397994564543`*^9}]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{Automatic, 154}, {Automatic, 17}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 295, 9, 86, "Text"],
Cell[843, 31, 410, 10, 27, "Input"],
Cell[CellGroupData[{
Cell[1278, 45, 458, 13, 27, "Input"],
Cell[1739, 60, 306, 9, 50, "Output"]
}, Open  ]],
Cell[2060, 72, 184, 4, 26, "Text"],
Cell[2247, 78, 1029, 29, 43, "Input"],
Cell[CellGroupData[{
Cell[3301, 111, 129, 2, 27, "Input"],
Cell[3433, 115, 757, 23, 67, "Output"]
}, Open  ]],
Cell[4205, 141, 259, 5, 41, "Text"],
Cell[4467, 148, 406, 10, 27, "Input"],
Cell[4876, 160, 323, 6, 41, "Text"],
Cell[5202, 168, 189, 4, 27, "Input"],
Cell[CellGroupData[{
Cell[5416, 176, 129, 2, 27, "Input"],
Cell[5548, 180, 756, 23, 67, "Output"]
}, Open  ]],
Cell[6319, 206, 143, 2, 26, "Text"],
Cell[6465, 210, 286, 8, 27, "Input"],
Cell[CellGroupData[{
Cell[6776, 222, 534, 16, 27, "Input"],
Cell[7313, 240, 242, 8, 66, "Output"]
}, Open  ]],
Cell[7570, 251, 1737, 51, 58, "Input"],
Cell[CellGroupData[{
Cell[9332, 306, 128, 2, 27, "Input"],
Cell[9463, 310, 917, 29, 109, "Output"]
}, Open  ]],
Cell[10395, 342, 409, 11, 27, "Input"],
Cell[10807, 355, 209, 5, 27, "Input"],
Cell[CellGroupData[{
Cell[11041, 364, 131, 2, 27, "Input"],
Cell[11175, 368, 969, 31, 135, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
