(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18535,        497]
NotebookOptionsPosition[     17151,        450]
NotebookOutlinePosition[     17491,        465]
CellTagsIndexPosition[     17448,        462]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Lagrange Interpolation Formula and Reproducing Kernel \
Bases",
 FontSize->14,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.505334622758717*^9, 3.505334629293929*^9}, {
  3.505691735878891*^9, 3.50569174603734*^9}}],

Cell["Parameters.", "Text",
 CellChangeTimes->{{3.5053346138569*^9, 3.505334616326565*^9}, 
   3.50533467939102*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"maxDegree", " ", "=", " ", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.505334494946567*^9, 3.5053345219349833`*^9}, {
  3.5056921605939074`*^9, 3.505692173982709*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numSamples", " ", "=", " ", 
   RowBox[{"maxDegree", "+", "1"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.505334519581159*^9, 3.505334530487814*^9}}],

Cell["Sampling locations / interpolation points.", "Text",
 CellChangeTimes->{{3.505334574545249*^9, 3.505334581358253*^9}, 
   3.505334677519573*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"locs", " ", "=", " ", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", "numSamples"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.505331652155719*^9, 3.505331690645483*^9}, {
  3.505331777032166*^9, 3.505331791677904*^9}, {3.505333291113247*^9, 
  3.505333316529628*^9}, {3.505334534993227*^9, 3.505334551810073*^9}}],

Cell["Construct kernal matrix / Vandermonde matrix.", "Text",
 CellChangeTimes->{{3.505334669632889*^9, 3.505334675374852*^9}, {
  3.505691472541057*^9, 3.5056914784737883`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"V", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", " ", 
    RowBox[{"0", ",", " ", 
     RowBox[{"{", 
      RowBox[{"numSamples", ",", "numSamples"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.505333258165943*^9, 3.505333264729398*^9}, {
  3.505333327851609*^9, 3.5053333647063932`*^9}, {3.505334555368331*^9, 
  3.505334563631126*^9}}],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", " ", "=", " ", "1"}], ",", " ", 
   RowBox[{"i", "\[LessEqual]", "numSamples"}], ",", " ", 
   RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{"For", "[", " ", 
    RowBox[{
     RowBox[{"j", " ", "=", " ", "0"}], ",", " ", 
     RowBox[{"j", " ", "\[LessEqual]", " ", "maxDegree"}], ",", " ", 
     RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", 
          RowBox[{"j", "+", "1"}]}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{
        RowBox[{"locs", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "^", "j"}]}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.505333373358753*^9, 3.505333433674686*^9}, {
  3.505334205866081*^9, 3.505334222146042*^9}, {3.505334682388636*^9, 
  3.505334690224608*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "V", "]"}]], "Input",
 CellChangeTimes->{{3.505333423406625*^9, 3.505333426146048*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"-", "0.8464911975644531`"}], "0.716547347554102`", 
      RowBox[{"-", "0.6065510223427042`"}], "0.513440101286819`"},
     {"1", "0.9821663928727955`", "0.9646508232887585`", 
      "0.9474476194912924`", "0.9305512108716796`"},
     {"1", 
      RowBox[{"-", "0.2311936363187166`"}], "0.05345049747427099`", 
      RowBox[{"-", "0.012357414874121087`"}], "0.0028569556802470497`"},
     {"1", "0.6697444526188372`", "0.44855763181370584`", 
      "0.3004189855870723`", "0.2012039490583201`"},
     {"1", "0.5756738128955896`", "0.3314003388537463`", 
      "0.19077849666282656`", "0.10982618459237788`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.50533342656091*^9, 3.5053334364137897`*^9}, {
   3.505334216094035*^9, 3.5053342322457447`*^9}, {3.505335161063273*^9, 
   3.505335165186598*^9}, 3.5056910804827642`*^9, 3.505691660427649*^9, 
   3.505691695868042*^9, {3.5056917269870243`*^9, 3.505691752279366*^9}, {
   3.5056921652756968`*^9, 3.505692196925878*^9}}]
}, Open  ]],

Cell["\<\
Construct dual monomial basis functions by inverting the kernel matrix and \
expanding in monomial reference basis.\
\>", "Text",
 CellChangeTimes->{{3.50533471629522*^9, 3.505334721367051*^9}, {
  3.505334776167995*^9, 3.5053347838795967`*^9}, {3.5056914851302967`*^9, 
  3.50569148825795*^9}, {3.505691572164542*^9, 3.5056915764203444`*^9}, {
  3.505691765549996*^9, 3.505691768957343*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SV", " ", "=", " ", 
   RowBox[{"Inverse", "[", "V", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.505336355218672*^9, 3.505336361799757*^9}, 
   3.50569160034258*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dm", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", "numSamples"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.505334892485857*^9, 3.5053349146224403`*^9}, {
  3.5053350651575527`*^9, 3.5053350808798122`*^9}, {3.505691611720397*^9, 
  3.505691616101995*^9}}],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", "=", "1"}], ",", 
   RowBox[{"i", "\[LessEqual]", "numSamples"}], ",", 
   RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"j", "=", "0"}], ",", " ", 
     RowBox[{"j", "<=", "maxDegree"}], ",", 
     RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Dm", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "+=", 
       RowBox[{
        RowBox[{"SV", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"j", "+", "1"}], ",", "i"}], "]"}], "]"}], "*", 
        SuperscriptBox["x", "j"]}]}], ";"}]}], "\[IndentingNewLine]", "]"}]}],
   "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.505334733673307*^9, 3.505334792925131*^9}, {
   3.505334863756117*^9, 3.505334889734768*^9}, {3.5053349218306704`*^9, 
   3.505334962423862*^9}, {3.505335085681094*^9, 3.505335185690233*^9}, 
   3.505335293046471*^9, 3.505336367993575*^9, {3.505336638561694*^9, 
   3.505336642158873*^9}, {3.505691624662785*^9, 3.5056916251428137`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "Dm", "]"}]], "Input",
 CellChangeTimes->{{3.50533493916306*^9, 3.505334946326589*^9}, {
  3.5053351033277817`*^9, 3.5053351048076687`*^9}, {3.5053351889529448`*^9, 
  3.50533519190311*^9}, {3.505691634911292*^9, 3.505691635701906*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"-", "0.03608379980903309`"}], "-", 
        RowBox[{"0.002779157023613976`", " ", "x"}], "+", 
        RowBox[{"0.45080354678857226`", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"0.8228322938931516`", " ", 
         SuperscriptBox["x", "3"]}], "+", 
        RowBox[{"0.4121598849110253`", " ", 
         SuperscriptBox["x", "4"]}]}]},
      {
       RowBox[{"0.2677735624400923`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.6095929774843052`", " ", "x"}], "-", 
        RowBox[{"2.7003337291457292`", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"0.5952554869406441`", " ", 
         SuperscriptBox["x", "3"]}], "+", 
        RowBox[{"3.5488183908932847`", " ", 
         SuperscriptBox["x", "4"]}]}]},
      {
       RowBox[{"0.5906376042437891`", "\[InvisibleSpace]", "-", 
        RowBox[{"1.8114925340173826`", " ", "x"}], "+", 
        RowBox[{"0.5101542649354887`", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"2.5447847153770145`", " ", 
         SuperscriptBox["x", "3"]}], "-", 
        RowBox[{"1.8425868976752628`", " ", 
         SuperscriptBox["x", "4"]}]}]},
      {
       RowBox[{
        RowBox[{"-", "2.7561483613903137`"}], "-", 
        RowBox[{"7.583469234643762`", " ", "x"}], "+", 
        RowBox[{"22.859518463727163`", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"11.959816539851186`", " ", 
         SuperscriptBox["x", "3"]}], "-", 
        RowBox[{"24.908221880125645`", " ", 
         SuperscriptBox["x", "4"]}]}]},
      {
       RowBox[{"2.9338209945154654`", "\[InvisibleSpace]", "+", 
        RowBox[{"8.788147948200454`", " ", "x"}], "-", 
        RowBox[{"21.120142546305495`", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"13.086513474394405`", " ", 
         SuperscriptBox["x", "3"]}], "+", 
        RowBox[{"22.789830501996597`", " ", 
         SuperscriptBox["x", "4"]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.505334941799346*^9, 3.505334966841339*^9}, {
   3.5053351054537897`*^9, 3.50533513675609*^9}, {3.5053351722474003`*^9, 
   3.505335192298276*^9}, {3.5053352771712646`*^9, 3.505335298623527*^9}, 
   3.505336372848015*^9, 3.505336643560936*^9, 3.50569108060533*^9, {
   3.5056916361208553`*^9, 3.505691660542923*^9}, 3.5056916959858294`*^9, {
   3.5056917271019497`*^9, 3.505691752394356*^9}, {3.5056921653922853`*^9, 
   3.505692197026115*^9}}]
}, Open  ]],

Cell["Construct Lagranage interpolation functions.", "Text",
 CellChangeTimes->{{3.5053347013910522`*^9, 3.5053347271513367`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"L", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"1", ",", "numSamples"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.50533540091119*^9, {3.505335546896304*^9, 3.5053355469998302`*^9}}],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", "=", "1"}], ",", 
   RowBox[{"i", "\[LessEqual]", "numSamples"}], ",", 
   RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"j", "=", "1"}], ",", 
     RowBox[{"j", "<=", "numSamples"}], ",", 
     RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[NotEqual]", "j"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"L", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", 
            RowBox[{"locs", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], ")"}], " ", "/", "  ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"locs", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "-", 
            RowBox[{"locs", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}]}], ";"}]}], " ", 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.505335422727439*^9, 3.505335551602105*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Expand", "[", "L", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5053354194902983`*^9, 3.505335420494471*^9}, {
  3.505335513311179*^9, 3.505335519119607*^9}, {3.505335564018017*^9, 
  3.5053355718805647`*^9}, {3.505336417354548*^9, 3.505336418144002*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"-", "0.03608379980903399`"}], "-", 
        RowBox[{"0.002779157023614448`", " ", "x"}], "+", 
        RowBox[{"0.45080354678857143`", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"0.8228322938931524`", " ", 
         SuperscriptBox["x", "3"]}], "+", 
        RowBox[{"0.41215988491102173`", " ", 
         SuperscriptBox["x", "4"]}]}]},
      {
       RowBox[{"0.26777356244009354`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.609592977484309`", " ", "x"}], "-", 
        RowBox[{"2.7003337291457377`", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"0.595255486940649`", " ", 
         SuperscriptBox["x", "3"]}], "+", 
        RowBox[{"3.5488183908932958`", " ", 
         SuperscriptBox["x", "4"]}]}]},
      {
       RowBox[{"0.5906376042437901`", "\[InvisibleSpace]", "-", 
        RowBox[{"1.8114925340173818`", " ", "x"}], "+", 
        RowBox[{"0.5101542649354864`", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"2.544784715377012`", " ", 
         SuperscriptBox["x", "3"]}], "-", 
        RowBox[{"1.8425868976752584`", " ", 
         SuperscriptBox["x", "4"]}]}]},
      {
       RowBox[{
        RowBox[{"-", "2.756148361390317`"}], "-", 
        RowBox[{"7.583469234643781`", " ", "x"}], "+", 
        RowBox[{"22.859518463727216`", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"11.959816539851218`", " ", 
         SuperscriptBox["x", "3"]}], "-", 
        RowBox[{"24.908221880125698`", " ", 
         SuperscriptBox["x", "4"]}]}]},
      {
       RowBox[{"2.9338209945154667`", "\[InvisibleSpace]", "+", 
        RowBox[{"8.788147948200468`", " ", "x"}], "-", 
        RowBox[{"21.12014254630553`", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"13.086513474394426`", " ", 
         SuperscriptBox["x", "3"]}], "+", 
        RowBox[{"22.789830501996637`", " ", 
         SuperscriptBox["x", "4"]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.505335519504225*^9, 3.505335572615556*^9}, 
   3.505336388659059*^9, 3.505336418791597*^9, 3.505336649104919*^9, 
   3.505691080705206*^9, {3.505691645604321*^9, 3.50569166064268*^9}, 
   3.5056916960696583`*^9, {3.50569172720358*^9, 3.5056917524940863`*^9}, {
   3.50569216549226*^9, 3.505692197125989*^9}}]
}, Open  ]],

Cell["\<\
Compare dual kernel functions with Lagrange interpolation formula. Note that \
the maximum error will necessarily be at x = 1 (also compare visually the Dm \
and L matrix).\
\>", "Text",
 CellChangeTimes->{{3.505335579208807*^9, 3.505335587381938*^9}, {
  3.505691245296474*^9, 3.505691255325498*^9}, {3.5056913822466173`*^9, 
  3.5056914160708*^9}, {3.505691649732881*^9, 3.505691650157298*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"maxDiff", " ", "=", " ", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.5056912910025883`*^9, 3.505691302918458*^9}}],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", "=", "1"}], ",", " ", 
   RowBox[{"i", "\[LessEqual]", "numSamples"}], ",", 
   RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{"maxDiff", " ", "=", " ", 
    RowBox[{"Max", "[", 
     RowBox[{"maxDiff", ",", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Dm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "-", 
         RowBox[{"Expand", "[", 
          RowBox[{"L", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "/.", 
        RowBox[{"x", "\[Rule]", "1"}]}], ")"}]}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.505691269884194*^9, 3.50569128409548*^9}, {
  3.5056913172952003`*^9, 3.505691363367673*^9}, {3.505691679329688*^9, 
  3.505691679734975*^9}, {3.505691716761674*^9, 3.5056917200160303`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["maxDiff"], "Input",
 CellChangeTimes->{{3.5056913560254307`*^9, 3.505691357527779*^9}}],

Cell[BoxData["6.536438057480609`*^-15"], "Output",
 CellChangeTimes->{{3.50569135813386*^9, 3.505691368812809*^9}, {
  3.505691655450733*^9, 3.505691660725374*^9}, {3.505691691560423*^9, 
  3.505691752594219*^9}, {3.5056921655750027`*^9, 3.505692197209248*^9}}]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{130, Automatic}, {Automatic, 0}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 247, 5, 28, "Text"],
Cell[795, 27, 116, 2, 26, "Text"],
Cell[914, 31, 204, 4, 27, "Input"],
Cell[1121, 37, 184, 4, 27, "Input"],
Cell[1308, 43, 150, 2, 26, "Text"],
Cell[1461, 47, 448, 11, 27, "Input"],
Cell[1912, 60, 178, 2, 26, "Text"],
Cell[2093, 64, 393, 10, 27, "Input"],
Cell[2489, 76, 948, 23, 88, "Input"],
Cell[CellGroupData[{
Cell[3462, 103, 129, 2, 27, "Input"],
Cell[3594, 107, 1528, 32, 105, "Output"]
}, Open  ]],
Cell[5137, 142, 402, 7, 41, "Text"],
Cell[5542, 151, 204, 5, 27, "Input"],
Cell[5749, 158, 323, 7, 27, "Input"],
Cell[6075, 167, 1104, 26, 112, "Input"],
Cell[CellGroupData[{
Cell[7204, 197, 278, 4, 27, "Input"],
Cell[7485, 203, 3030, 71, 119, "Output"]
}, Open  ]],
Cell[10530, 277, 130, 1, 26, "Text"],
Cell[10663, 280, 244, 6, 27, "Input"],
Cell[10910, 288, 1174, 31, 118, "Input"],
Cell[CellGroupData[{
Cell[12109, 323, 310, 5, 27, "Input"],
Cell[12422, 330, 2892, 69, 119, "Output"]
}, Open  ]],
Cell[15329, 402, 406, 7, 41, "Text"],
Cell[15738, 411, 151, 3, 27, "Input"],
Cell[15892, 416, 853, 21, 58, "Input"],
Cell[CellGroupData[{
Cell[16770, 441, 101, 1, 27, "Input"],
Cell[16874, 444, 261, 3, 30, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
